Welcome to the Research Software Encyclopedia! — The Research Software Encyclopedia 11 documentation

# Welcome to the Research Software Encyclopedia!

The Research Software Encyclopedia (rse) is software to query and otherwise interact with a database of research software, and a research software taxonomy. It is intended for research software engineers to be able to better qualify and quantify the work that they do.

The module is licensed under the MPL 2.0 LICENSE.

Contents:

- rse package
  - Subpackages
    - rse.app package
    - rse.client package
    - rse.logger package
    - rse.main package
    - rse.utils package
  - Submodules
  - rse.defaults module
  - rse.exceptions module
  - rse.version module
  - Module contents

## Indices and tables

- Module Index